Struct opcua_types::array::Array [−][src]
An array is a vector of values with an optional number of dimensions. It is expected that the multi-dimensional array is valid, or it might not be encoded or decoded properly. The dimensions should match the number of values, or the array is invalid.
Fields
values: Vec<Variant>Values are stored sequentially
dimensions: Vec<u32>Multi dimension array which can contain any scalar type, all the same type. Nested arrays are rejected. Higher rank dimensions are serialized first. For example an array with dimensions [2,2,2] is written in this order - [0,0,0], [0,0,1], [0,1,0], [0,1,1], [1,0,0], [1,0,1], [1,1,0], [1,1,1].
Implementations