Struct opcua_types::basic_types::ExtensionObject [] [src]

pub struct ExtensionObject {
    pub node_id: NodeId,
    pub body: ExtensionObjectEncoding,
}

A structure that contains an application specific data type that may not be recognized by the receiver. Data type ID 22

Fields

Methods

impl ExtensionObject
[src]

[src]

Creates a null extension object, i.e. one with no value or payload

[src]

[src]

[src]

Creates an extension object with the specified node id and the encodable object as its payload. The body is set to a byte string containing the encoded struct.

[src]

Decodes the inner content of the extension object and returns it. The node id is ignored for decoding. The caller supplies the binary encoder impl that should be used to extract the data. Errors result in a decoding error.