Struct opcua_types::basic_types::QualifiedName [] [src]

pub struct QualifiedName {
    pub namespace_index: UInt16,
    pub name: UAString,
}

A numeric identifier for a error or condition that is associated with a value or an operation. Data type ID 19 A name qualified by a namespace. Data type ID 20

Fields

The namespace index.

The name.

Methods

impl QualifiedName
[src]

[src]

[src]

[src]