Struct opcua_types::byte_string::ByteString [] [src]

pub struct ByteString {
    pub value: Option<Vec<u8>>,
}

A sequence of octets.

Fields

Methods

impl ByteString
[src]

[src]

Create a null string (not the same as an empty string)

[src]

Test if the string is null

[src]

Test if the string is null or empty

[src]

Creates a byte string from a Base64 encoded string

[src]

Encodes the bytestring as a Base64 encoded string

[src]

Creates a nonce - 32 bytes of random data

[src]

Create a byte string with a number of random characters. Can be used to create a nonce or a similar reason.