DataTypeTree

Struct DataTypeTree 

pub struct DataTypeTree { /* private fields */ }
Data type tree, used for loading custom types at runtime.

Implementations

Source

impl DataTypeTree

pub fn new(parent_ids: ParentIds) -> Self

Create a new data type tree with the given parent IDs.

Parent IDs should be populated before starting to populate the type tree.

pub fn add_type(&mut self, id: NodeId, info: impl Into<TypeInfo>)

Add a type to the tree.

pub fn get_type<'a>(&'a self, id: &NodeId) -> Option<TypeInfoRef<'a>>

Get a type from the tree.

pub fn get_struct_type(&self, id: &NodeId) -> Option<&Arc<StructTypeInfo>>

Get a struct type from the tree.

pub fn parent_ids_mut(&mut self) -> &mut ParentIds

Get a mutable reference to the parent ID map.

pub fn parent_ids(&self) -> &ParentIds

Get a reference to the parent ID map.

pub fn encoding_to_data_type(&self) -> &HashMap<NodeId, NodeId>

Get the inner map from encoding to data type ID.