pub struct DynamicStructure { /* private fields */ }Expand description
A type representing an OPC-UA structure decoded dynamically. This can use runtime information to properly encode and decode binary information. In order to make the type encodable, it contains references to a StructTypeInfo describing the type it contains, as well as the DataTypeTree containing any types it references.
This type can be used to reason about data on a server without explicitly defining the server types in code, which is useful if you want to create a generic client that can work with data from any server.
Internally it is simply an array of Variant.
Note that this type is intended to support all encoding/decoding types in the OPC-UA standard, which is more than what the encoding macros currently do. This includes structurs with optional fields, unions, and multi-dimensional arrays, none of which are used in the core types.
Implementations
Sourceimpl DynamicStructure
impl DynamicStructure
Sourcepub fn new_struct(
type_def: Arc<StructTypeInfo>,
type_tree: Arc<DataTypeTree>,
data: Vec<Variant>,
) -> Result<Self, Error>
pub fn new_struct( type_def: Arc<StructTypeInfo>, type_tree: Arc<DataTypeTree>, data: Vec<Variant>, ) -> Result<Self, Error>
Create a new struct, validating that it matches the provided type definition.
Sourcepub fn new_union(
type_def: Arc<StructTypeInfo>,
type_tree: Arc<DataTypeTree>,
data: Variant,
discriminant: u32,
) -> Result<Self, Error>
pub fn new_union( type_def: Arc<StructTypeInfo>, type_tree: Arc<DataTypeTree>, data: Variant, discriminant: u32, ) -> Result<Self, Error>
Create a new union, validating that it matches the provided type definition.
Sourcepub fn new_null_union(
type_def: Arc<StructTypeInfo>,
type_tree: Arc<DataTypeTree>,
) -> Self
pub fn new_null_union( type_def: Arc<StructTypeInfo>, type_tree: Arc<DataTypeTree>, ) -> Self
Create a new union, with value null.
Sourcepub fn get_field(&self, index: usize) -> Option<&Variant>
pub fn get_field(&self, index: usize) -> Option<&Variant>
Get a reference to the field at index
Sourcepub fn get_field_by_name(&self, name: &str) -> Option<&Variant>
pub fn get_field_by_name(&self, name: &str) -> Option<&Variant>
Get a reference to the field with the given name.