StructTypeInfo

Struct StructTypeInfo 

pub struct StructTypeInfo {
    pub structure_type: StructureType,
    pub fields: Vec<ParsedStructureField>,
    pub index_by_name: HashMap<String, usize>,
    pub encoding_ids: EncodingIds,
    pub is_abstract: bool,
    pub node_id: NodeId,
    pub name: String,
}
Parsed info about a structure type.

Fields

structure_type: StructureType

Structure variant. Structure, StructureWithOptionalFields, or Union.

fields: Vec<ParsedStructureField>

List of structure fields. The order is significant.

index_by_name: HashMap<String, usize>

Field index by name.

encoding_ids: EncodingIds

Collection of encoding IDs.

is_abstract: bool

Whether this type is abstract and cannot be instantiated.

node_id: NodeId

Structure node ID.

name: String

Structure name.

Implementations

Source

impl StructTypeInfo

pub fn get_field(&self, idx: usize) -> Option<&ParsedStructureField>

Get a field by index.

pub fn get_field_by_name(&self, idx: &str) -> Option<&ParsedStructureField>

Get a field by name.

pub fn is_supported(&self) -> bool

Return whether this struct is supported by the current version of the library. Types that are not supported will panic on encoding, and be skipped when decoding.

Currently this is only structures and unions with subtyped values.