Enum opcua_types::data_types::MessageSecurityMode [] [src]

pub enum MessageSecurityMode {
    Invalid,
    None,
    Sign,
    SignAndEncrypt,
}

The MessageSecurityMode is an enumeration that specifies what security should be applied to messages exchanges during a Session.

Variants

The MessageSecurityMode is invalid. This value is the default value to avoid an accidental choice of no security is applied. This choice will always be rejected.

No security is applied.

All messages are signed but not encrypted.

All messages are signed and encrypted.