pub trait SimpleBinaryDecodable: Sized {
// Required method
fn decode<S: Read + ?Sized>(
stream: &mut S,
decoding_options: &DecodingOptions,
) -> EncodingResult<Self>;
}Expand description
Trait for decoding a type that cannot contain any custom types from OPC UA binary. Used in some core modules to decode raw binary messages.
Required Methods
Sourcefn decode<S: Read + ?Sized>(
stream: &mut S,
decoding_options: &DecodingOptions,
) -> EncodingResult<Self>
fn decode<S: Read + ?Sized>( stream: &mut S, decoding_options: &DecodingOptions, ) -> EncodingResult<Self>
Decode Self from the byte stream.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".