#[repr(i32)]pub enum NamingRuleType {
Mandatory = 1,
Optional = 2,
Constraint = 3,
}Variants
Mandatory = 1
The BrowseName must appear in all instances of the type.
Optional = 2
The BrowseName may appear in an instance of the type.
Constraint = 3
The modelling rule defines a constraint and the BrowseName is not used in an instance of the type.