#[repr(i32)]pub enum NegotiationStatus {
InProgress = 0,
Complete = 1,
Failed = 2,
Unknown = 3,
NoNegotiation = 4,
}Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part22/5.3.1/#5.3.1.4
Variants
InProgress = 0
The auto-negotiation protocol is running and negotiation is currently in-progress.
Complete = 1
The auto-negotiation protocol has completed successfully.
Failed = 2
The auto-negotiation protocol has failed.
Unknown = 3
The auto-negotiation status is not currently known, this could be because it is still negotiating or the protocol cannot run (e.g., if no medium is present).
NoNegotiation = 4
No auto-negotiation is executed. The auto-negotiation function is either not supported on this interface or has not been enabled.