#[repr(i32)]pub enum PortIdSubtype {
InterfaceAlias = 1,
PortComponent = 2,
MacAddress = 3,
NetworkAddress = 4,
InterfaceName = 5,
AgentCircuitId = 6,
Local = 7,
}Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part22/5.3.1/#5.3.1.10
Variants
InterfaceAlias = 1
Represents a port identifier based on the ifAlias MIB object defined in IETF RFC 2863.
PortComponent = 2
Represents a port identifier based on the value of entPhysicalAlias (defined in IETF RFC 2737) for a port component (i.e., entPhysicalClass value of port(10) or backplane(4)), within the containing chassis.
MacAddress = 3
Represents a port identifier based on a unicast source address (encoded in network byte order and IEEE 802.3 canonical bit order) which has been detected by the agent and associated with a particular port (IEEE Std 802-2014).
NetworkAddress = 4
Represents a port identifier based on a network address, detected by the agent and associated with a particular port.
InterfaceName = 5
Represents a port identifier based on the ifName MIB object, defined in IETF RFC 2863.
AgentCircuitId = 6
Represents a port identifier based on the agent-local identifier of the circuit (defined in IETF RFC 3046), detected by the agent and associated with a particular port.
Local = 7
Represents a port identifier based on a value locally assigned.