IntoNodeIdRef

Trait IntoNodeIdRef 

pub trait IntoNodeIdRef<'a> {
    type TIdentifier: IdentifierRef + Clone + Copy + 'a;

    // Required method
    fn into_node_id_ref(self) -> NodeIdRef<Self::TIdentifier>;
}
Trait that allows converting a type into a NodeIdRef. This is used instead of Into to allow for simple function signatures.

This trait is implemented for copyable types that can be compared to node IDs, such as the core ObjectId, VariableId, etc. enums, and tuples (u16, T), where T is an IdentifierRef, which can be compared to an Identifier. This includes types such as &[u8], &str, &Guid, and u32.

It is also implemented for &NodeId.

Required Associated Types

type TIdentifier: IdentifierRef + Clone + Copy + 'a

The inner identifier type.

Required Methods

fn into_node_id_ref(self) -> NodeIdRef<Self::TIdentifier>

Get a reference to this as a NodeIdRef.

Implementations on Foreign Types

Source

impl<'a, T> IntoNodeIdRef<'a> for (u16, T)
where T: IdentifierRef + Clone + Copy + 'a,

Implementors