Operand

Enum Operand 

pub enum Operand {
    ElementOperand(ElementOperand),
    LiteralOperand(LiteralOperand),
    AttributeOperand(AttributeOperand),
    SimpleAttributeOperand(SimpleAttributeOperand),
}
A filter operand.

Variants



ElementOperand(ElementOperand)

Operand pointing at another filter element.



LiteralOperand(LiteralOperand)

Operand resolving to a literal value.



AttributeOperand(AttributeOperand)

Operand resolving to an attribute of some node.



SimpleAttributeOperand(SimpleAttributeOperand)

Operand resolving to an attribute of some type.

Implementations

Source

impl Operand

pub fn element(index: u32) -> Operand

Create an element operand with the given index.

pub fn literal<T>(literal: T) -> Operand
where T: Into<LiteralOperand>,

Create a literal operand with the given type.

pub fn simple_attribute<T>( type_definition_id: T, browse_path: &str, attribute_id: AttributeId, index_range: NumericRange, ) -> Operand
where T: Into<NodeId>,

Creates a simple attribute operand. The browse path is the browse name using / as a separator.

pub fn operand_type(&self) -> OperandType

Get the operand type.

pub fn is_element(&self) -> bool

Return true if the operand is an element operand.

pub fn is_literal(&self) -> bool

Return true if the operand is a literal operand.

pub fn is_attribute(&self) -> bool

Return true if the operand is an attribute operand.

pub fn is_simple_attribute(&self) -> bool

Return true if the operand is a simple attribute operand.