ResponseHeader

Struct ResponseHeader 

pub struct ResponseHeader {
    pub timestamp: UtcTime,
    pub request_handle: IntegerId,
    pub service_result: StatusCode,
    pub service_diagnostics: DiagnosticInfo,
    pub string_table: Option<Vec<UAString>>,
    pub additional_header: ExtensionObject,
}
The ResponseHeader contains information common to every response from server to client.

Fields

timestamp: UtcTime

Response timestamp.

request_handle: IntegerId

Handle of the request this message is responding to.

service_result: StatusCode

Status of the service call as a whole.

service_diagnostics: DiagnosticInfo

Requested diagnostics.

string_table: Option<Vec<UAString>>

String table for the message.

additional_header: ExtensionObject

Reserved space for additional header details.

Implementations

Source

impl ResponseHeader

pub fn new_good(request_header: impl AsRequestHandle) -> ResponseHeader

Create a new response header with status Good.

pub fn new_service_result( request_header: impl AsRequestHandle, service_result: StatusCode, ) -> ResponseHeader

Create a new response header with given status.

pub fn new_timestamped_service_result( timestamp: DateTime, request_header: impl AsRequestHandle, service_result: StatusCode, ) -> ResponseHeader

Create a new response header with given status and timestamp.

pub fn null() -> ResponseHeader

For testing, nothing else