Struct opcua_types::service_types::SamplingIntervalDiagnosticsDataType [−][src]
pub struct SamplingIntervalDiagnosticsDataType {
pub sampling_interval: f64,
pub monitored_item_count: u32,
pub max_monitored_item_count: u32,
pub disabled_monitored_item_count: u32,
}Fields
sampling_interval: f64monitored_item_count: u32max_monitored_item_count: u32disabled_monitored_item_count: u32Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.