Struct opcua_types::service_types::StructureDefinition [−][src]
pub struct StructureDefinition {
pub default_encoding_id: NodeId,
pub base_data_type: NodeId,
pub structure_type: StructureType,
pub fields: Option<Vec<StructureField>>,
}Fields
default_encoding_id: NodeIdbase_data_type: NodeIdstructure_type: StructureTypefields: Option<Vec<StructureField>>Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.