Struct opcua_types::service_types::StructureField [−][src]
pub struct StructureField {
pub name: UAString,
pub description: LocalizedText,
pub data_type: NodeId,
pub value_rank: i32,
pub array_dimensions: Option<Vec<u32>>,
pub max_string_length: u32,
pub is_optional: bool,
}Fields
name: UAStringdescription: LocalizedTextdata_type: NodeIdvalue_rank: i32array_dimensions: Option<Vec<u32>>max_string_length: u32is_optional: boolTrait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.