Enum opcua_types::status_codes::StatusCode [] [src]

pub enum StatusCode {
    Good,
    GoodSubscriptionTransferred,
    GoodCompletesAsynchronously,
    GoodOverload,
    GoodClamped,
    GoodLocalOverride,
    GoodEntryInserted,
    GoodEntryReplaced,
    GoodNoData,
    GoodMoreData,
    GoodCommunicationEvent,
    GoodShutdownEvent,
    GoodCallAgain,
    GoodNonCriticalTimeout,
    GoodResultsMayBeIncomplete,
    GoodDataIgnored,
    GoodEdited,
    GoodPostActionFailed,
    GoodDependentValueChanged,
    UncertainReferenceOutOfServer,
    UncertainNoCommunicationLastUsableValue,
    UncertainLastUsableValue,
    UncertainSubstituteValue,
    UncertainInitialValue,
    UncertainSensorNotAccurate,
    UncertainEngineeringUnitsExceeded,
    UncertainSubNormal,
    UncertainDataSubNormal,
    UncertainReferenceNotDeleted,
    UncertainNotAllNodesAvailable,
    UncertainDominantValueChanged,
    UncertainDependentValueChanged,
    BadUnexpectedError,
    BadInternalError,
    BadOutOfMemory,
    BadResourceUnavailable,
    BadCommunicationError,
    BadEncodingError,
    BadDecodingError,
    BadEncodingLimitsExceeded,
    BadUnknownResponse,
    BadTimeout,
    BadServiceUnsupported,
    BadShutdown,
    BadServerNotConnected,
    BadServerHalted,
    BadNothingToDo,
    BadTooManyOperations,
    BadDataTypeIdUnknown,
    BadCertificateInvalid,
    BadSecurityChecksFailed,
    BadCertificateTimeInvalid,
    BadCertificateIssuerTimeInvalid,
    BadCertificateHostNameInvalid,
    BadCertificateUriInvalid,
    BadCertificateUseNotAllowed,
    BadCertificateIssuerUseNotAllowed,
    BadCertificateUntrusted,
    BadCertificateRevocationUnknown,
    BadCertificateIssuerRevocationUnknown,
    BadCertificateRevoked,
    BadCertificateIssuerRevoked,
    BadUserAccessDenied,
    BadIdentityTokenInvalid,
    BadIdentityTokenRejected,
    BadSecureChannelIdInvalid,
    BadInvalidTimestamp,
    BadNonceInvalid,
    BadSessionIdInvalid,
    BadSessionClosed,
    BadSessionNotActivated,
    BadSubscriptionIdInvalid,
    BadRequestHeaderInvalid,
    BadTimestampsToReturnInvalid,
    BadRequestCancelledByClient,
    BadNoCommunication,
    BadWaitingForInitialData,
    BadNodeIdInvalid,
    BadNodeIdUnknown,
    BadAttributeIdInvalid,
    BadIndexRangeInvalid,
    BadIndexRangeNoData,
    BadDataEncodingInvalid,
    BadDataEncodingUnsupported,
    BadNotReadable,
    BadNotWritable,
    BadOutOfRange,
    BadNotSupported,
    BadNotFound,
    BadObjectDeleted,
    BadNotImplemented,
    BadMonitoringModeInvalid,
    BadMonitoredItemIdInvalid,
    BadMonitoredItemFilterInvalid,
    BadMonitoredItemFilterUnsupported,
    BadFilterNotAllowed,
    BadStructureMissing,
    BadEventFilterInvalid,
    BadContentFilterInvalid,
    BadFilterOperandInvalid,
    BadContinuationPointInvalid,
    BadNoContinuationPoints,
    BadReferenceTypeIdInvalid,
    BadBrowseDirectionInvalid,
    BadNodeNotInView,
    BadServerUriInvalid,
    BadServerNameMissing,
    BadDiscoveryUrlMissing,
    BadSempahoreFileMissing,
    BadRequestTypeInvalid,
    BadSecurityModeRejected,
    BadSecurityPolicyRejected,
    BadTooManySessions,
    BadUserSignatureInvalid,
    BadApplicationSignatureInvalid,
    BadNoValidCertificates,
    BadRequestCancelledByRequest,
    BadParentNodeIdInvalid,
    BadReferenceNotAllowed,
    BadNodeIdRejected,
    BadNodeIdExists,
    BadNodeClassInvalid,
    BadBrowseNameInvalid,
    BadBrowseNameDuplicated,
    BadNodeAttributesInvalid,
    BadTypeDefinitionInvalid,
    BadSourceNodeIdInvalid,
    BadTargetNodeIdInvalid,
    BadDuplicateReferenceNotAllowed,
    BadInvalidSelfReference,
    BadReferenceLocalOnly,
    BadNoDeleteRights,
    BadServerIndexInvalid,
    BadViewIdUnknown,
    BadTooManyMatches,
    BadQueryTooComplex,
    BadNoMatch,
    BadMaxAgeInvalid,
    BadHistoryOperationInvalid,
    BadHistoryOperationUnsupported,
    BadWriteNotSupported,
    BadTypeMismatch,
    BadMethodInvalid,
    BadArgumentsMissing,
    BadTooManySubscriptions,
    BadTooManyPublishRequests,
    BadNoSubscription,
    BadSequenceNumberUnknown,
    BadMessageNotAvailable,
    BadInsufficientClientProfile,
    BadTcpServerTooBusy,
    BadTcpMessageTypeInvalid,
    BadTcpSecureChannelUnknown,
    BadTcpMessageTooLarge,
    BadTcpNotEnoughResources,
    BadTcpInternalError,
    BadTcpEndpointUrlInvalid,
    BadRequestInterrupted,
    BadRequestTimeout,
    BadSecureChannelClosed,
    BadSecureChannelTokenUnknown,
    BadSequenceNumberInvalid,
    BadConfigurationError,
    BadNotConnected,
    BadDeviceFailure,
    BadSensorFailure,
    BadOutOfService,
    BadDeadbandFilterInvalid,
    BadRefreshInProgress,
    BadConditionAlreadyDisabled,
    BadConditionDisabled,
    BadEventIdUnknown,
    BadNoData,
    BadDataLost,
    BadDataUnavailable,
    BadEntryExists,
    BadNoEntryExists,
    BadTimestampNotSupported,
    BadInvalidArgument,
    BadConnectionRejected,
    BadDisconnect,
    BadConnectionClosed,
    BadInvalidState,
    BadEndOfStream,
    BadNoDataAvailable,
    BadWaitingForResponse,
    BadOperationAbandoned,
    BadExpectedStreamToBlock,
    BadWouldBlock,
    BadSyntaxError,
    BadMaxConnectionsReached,
    BadRequestTooLarge,
    BadResponseTooLarge,
    BadEventNotAcknowledgeable,
    BadInvalidTimestampArgument,
    BadProtocolVersionUnsupported,
    BadStateNotActive,
    BadFilterOperatorInvalid,
    BadFilterOperatorUnsupported,
    BadFilterOperandCountMismatch,
    BadFilterElementInvalid,
    BadFilterLiteralInvalid,
    BadIdentityChangeNotSupported,
    BadNotTypeDefinition,
    BadViewTimestampInvalid,
    BadViewParameterMismatch,
    BadViewVersionInvalid,
    BadConditionAlreadyEnabled,
    BadDialogNotActive,
    BadDialogResponseInvalid,
    BadConditionBranchAlreadyAcked,
    BadConditionBranchAlreadyConfirmed,
    BadConditionAlreadyShelved,
    BadConditionNotShelved,
    BadShelvingTimeOutOfRange,
    BadAggregateListMismatch,
    BadAggregateNotSupported,
    BadAggregateInvalidInputs,
    BadBoundNotFound,
    BadBoundNotSupported,
    BadAggregateConfigurationRejected,
    BadTooManyMonitoredItems,
    BadDominantValueChanged,
    BadDependentValueChanged,
    BadRequestNotAllowed,
    BadTooManyArguments,
    BadSecurityModeInsufficient,
    BadCertificateChainIncomplete,
}

Variants

Methods

impl StatusCode
[src]

[src]

Tests if the status code is bad

[src]

Tests if the status code is uncertain

[src]

Tests if the status code is good (i.e. not bad or uncertain)

[src]

Returns the descriptive name for the status code, e.g. to put a meaningful code in a log file

[src]

Returns the descriptive text for the status code

[src]

Takes an OPC UA status code as a UInt32 and returns the matching StatusCode, assuming there is one

[src]

Takes an OPC UA status code as a string and returns the matching StatusCode - assuming there is one