Struct opcua_types::string::UAString [−][src]
pub struct UAString { /* fields omitted */ }Expand description
To avoid naming conflict hell, the OPC UA String type is typed UAString so it does not collide
with the Rust String.
A string contains UTF-8 encoded characters or a null value. A null value is distinct from
being an empty string so internally, the code maintains that distinction by holding the value
as an Option<String>.
Implementations
This function is meant for use with NumericRange. It creates a substring from this string from min up to and inclusive of max. Note that min must have an index within the string but max is allowed to be beyond the end in which case the remainder of the string is returned (see docs for NumericRange).