pub struct AttributesMask(/* private fields */);Expand description
Bitmask for attributes
Implementations
Sourceimpl AttributesMask
impl AttributesMask
Sourcepub const ACCESS_LEVEL: Self
pub const ACCESS_LEVEL: Self
Indicates if the AccessLevel Attribute is set.
Sourcepub const ARRAY_DIMENSIONS: Self
pub const ARRAY_DIMENSIONS: Self
Indicates if the ArrayDimensions Attribute is set.
Sourcepub const CONTAINS_NO_LOOPS: Self
pub const CONTAINS_NO_LOOPS: Self
Indicates if the ContainsNoLoops Attribute is set.
Sourcepub const DESCRIPTION: Self
pub const DESCRIPTION: Self
Indicates if the Description Attribute is set.
Sourcepub const DISPLAY_NAME: Self
pub const DISPLAY_NAME: Self
Indicates if the DisplayName Attribute is set.
Sourcepub const EVENT_NOTIFIER: Self
pub const EVENT_NOTIFIER: Self
Indicates if the EventNotifier Attribute is set.
Sourcepub const EXECUTABLE: Self
pub const EXECUTABLE: Self
Indicates if the Executable Attribute is set.
Sourcepub const HISTORIZING: Self
pub const HISTORIZING: Self
Indicates if the Historizing Attribute is set.
Sourcepub const INVERSE_NAME: Self
pub const INVERSE_NAME: Self
Indicates if the InverseName Attribute is set.
Sourcepub const IS_ABSTRACT: Self
pub const IS_ABSTRACT: Self
Indicates if the IsAbstract Attribute is set.
Sourcepub const MINIMUM_SAMPLING_INTERVAL: Self
pub const MINIMUM_SAMPLING_INTERVAL: Self
Indicates if the MinimumSamplingInterval Attribute is set.
Sourcepub const USER_ACCESS_LEVEL: Self
pub const USER_ACCESS_LEVEL: Self
Indicates if the UserAccessLevel Attribute is set.
Sourcepub const USER_EXECUTABLE: Self
pub const USER_EXECUTABLE: Self
Indicates if the UserExecutable Attribute is set.
Sourcepub const USER_WRITE_MASK: Self
pub const USER_WRITE_MASK: Self
Indicates if the UserWriteMask Attribute is set.
Sourcepub const VALUE_RANK: Self
pub const VALUE_RANK: Self
Indicates if the ValueRank Attribute is set.
Sourcepub const WRITE_MASK: Self
pub const WRITE_MASK: Self
Indicates if the WriteMask Attribute is set.
Sourceimpl AttributesMask
impl AttributesMask
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl AttributesMask
impl AttributesMask
Sourcepub const fn iter(&self) -> Iter<AttributesMask>
pub const fn iter(&self) -> Iter<AttributesMask>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AttributesMask>
pub const fn iter_names(&self) -> IterNames<AttributesMask>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.