pub struct EndpointDescription {
pub endpoint_url: UAString,
pub server: ApplicationDescription,
pub server_certificate: ApplicationInstanceCertificate,
pub security_mode: MessageSecurityMode,
pub security_policy_uri: UAString,
pub user_identity_tokens: Option<Vec<UserTokenPolicy>>,
pub transport_profile_uri: UAString,
pub security_level: u8,
}Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part4/7.14
Fields
endpoint_url: UAStringserver: ApplicationDescriptionserver_certificate: ApplicationInstanceCertificatesecurity_mode: MessageSecurityModesecurity_policy_uri: UAStringuser_identity_tokens: Option<Vec<UserTokenPolicy>>transport_profile_uri: UAStringsecurity_level: u8Implementations
Sourceimpl EndpointDescription
impl EndpointDescription
Sourcepub fn find_policy(&self, token_type: UserTokenType) -> Option<&UserTokenPolicy>
pub fn find_policy(&self, token_type: UserTokenType) -> Option<&UserTokenPolicy>
Returns a reference to a policy that matches the supplied token type, otherwise None
Sourcepub fn find_policy_by_id(&self, policy_id: &str) -> Option<&UserTokenPolicy>
pub fn find_policy_by_id(&self, policy_id: &str) -> Option<&UserTokenPolicy>
Returns a reference to a policy that matches the supplied policy id