pub struct EndpointType {
pub endpoint_url: UAString,
pub security_mode: MessageSecurityMode,
pub security_policy_uri: UAString,
pub transport_profile_uri: UAString,
}Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part18/4.4.2
Fields
endpoint_url: UAStringsecurity_mode: MessageSecurityModesecurity_policy_uri: UAStringtransport_profile_uri: UAStringTrait Implementations
Sourceimpl BinaryDecodable for EndpointType
impl BinaryDecodable for EndpointType
Sourcefn decode<S: Read + ?Sized>(
stream: &mut S,
ctx: &Context<'_>,
) -> EncodingResult<Self>
fn decode<S: Read + ?Sized>( stream: &mut S, ctx: &Context<'_>, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.Sourceimpl BinaryEncodable for EndpointType
impl BinaryEncodable for EndpointType
Sourcefn byte_len(&self, ctx: &Context<'_>) -> usize
fn byte_len(&self, ctx: &Context<'_>) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write + ?Sized>(
&self,
stream: &mut S,
ctx: &Context<'_>,
) -> EncodingResult<()>
fn encode<S: Write + ?Sized>( &self, stream: &mut S, ctx: &Context<'_>, ) -> EncodingResult<()>
Encodes the instance to the write stream.
Sourcefn override_encoding(&self) -> Option<BuiltInDataEncoding>
fn override_encoding(&self) -> Option<BuiltInDataEncoding>
Override the extension object encoding used for this type.
This only makes sense if the type can only ever be encoded using a single
built-in encoding.
Sourceimpl Clone for EndpointType
impl Clone for EndpointType
Sourcefn clone(&self) -> EndpointType
fn clone(&self) -> EndpointType
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EndpointType
impl Debug for EndpointType
Sourceimpl Default for EndpointType
impl Default for EndpointType
Sourcefn default() -> EndpointType
fn default() -> EndpointType
Returns the “default value” for a type. Read more
Sourceimpl JsonDecodable for EndpointType
impl JsonDecodable for EndpointType
Sourcefn decode(
stream: &mut JsonStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> EncodingResult<Self>
fn decode( stream: &mut JsonStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> EncodingResult<Self>
Decode Self from a JSON stream.
Sourceimpl JsonEncodable for EndpointType
impl JsonEncodable for EndpointType
Sourcefn encode(
&self,
stream: &mut JsonStreamWriter<&mut dyn Write>,
ctx: &Context<'_>,
) -> EncodingResult<()>
fn encode( &self, stream: &mut JsonStreamWriter<&mut dyn Write>, ctx: &Context<'_>, ) -> EncodingResult<()>
Write the type to the provided JSON writer.
Sourceimpl MessageInfo for EndpointType
impl MessageInfo for EndpointType
Sourcefn json_type_id(&self) -> ObjectId
fn json_type_id(&self) -> ObjectId
The JSON type id associated with the message.
Sourcefn xml_type_id(&self) -> ObjectId
fn xml_type_id(&self) -> ObjectId
The XML type id associated with the message.
Sourcefn data_type_id(&self) -> DataTypeId
fn data_type_id(&self) -> DataTypeId
The data type id associated with the message.
Sourceimpl PartialEq for EndpointType
impl PartialEq for EndpointType
Sourceimpl UaNullable for EndpointType
impl UaNullable for EndpointType
Sourcefn is_ua_null(&self) -> bool
fn is_ua_null(&self) -> bool
Return true if this value is null, meaning it can be left out when
being encoded in JSON and XML encodings.
Sourceimpl XmlDecodable for EndpointType
impl XmlDecodable for EndpointType
Sourcefn decode(
stream: &mut XmlStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> EncodingResult<Self>
fn decode( stream: &mut XmlStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> EncodingResult<Self>
Decode a value from an XML stream.
Sourceimpl XmlEncodable for EndpointType
impl XmlEncodable for EndpointType
Sourcefn encode(
&self,
stream: &mut XmlStreamWriter<&mut dyn Write>,
ctx: &Context<'_>,
) -> EncodingResult<()>
fn encode( &self, stream: &mut XmlStreamWriter<&mut dyn Write>, ctx: &Context<'_>, ) -> EncodingResult<()>
Encode a value to an XML stream.
Sourceimpl XmlType for EndpointType
impl XmlType for EndpointType
impl StructuralPartialEq for EndpointType