pub struct HistoryReadValueId {
pub node_id: NodeId,
pub index_range: NumericRange,
pub data_encoding: QualifiedName,
pub continuation_point: ContinuationPoint,
}Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part4/5.11.3/#5.11.3.2
Fields
node_id: NodeIdindex_range: NumericRangedata_encoding: QualifiedNamecontinuation_point: ContinuationPointTrait Implementations
Sourceimpl BinaryDecodable for HistoryReadValueId
impl BinaryDecodable for HistoryReadValueId
Sourcefn decode<S: Read + ?Sized>(
stream: &mut S,
ctx: &Context<'_>,
) -> EncodingResult<Self>
fn decode<S: Read + ?Sized>( stream: &mut S, ctx: &Context<'_>, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.Sourceimpl BinaryEncodable for HistoryReadValueId
impl BinaryEncodable for HistoryReadValueId
Sourcefn byte_len(&self, ctx: &Context<'_>) -> usize
fn byte_len(&self, ctx: &Context<'_>) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write + ?Sized>(
&self,
stream: &mut S,
ctx: &Context<'_>,
) -> EncodingResult<()>
fn encode<S: Write + ?Sized>( &self, stream: &mut S, ctx: &Context<'_>, ) -> EncodingResult<()>
Encodes the instance to the write stream.
Sourcefn override_encoding(&self) -> Option<BuiltInDataEncoding>
fn override_encoding(&self) -> Option<BuiltInDataEncoding>
Override the extension object encoding used for this type.
This only makes sense if the type can only ever be encoded using a single
built-in encoding.
Sourceimpl Clone for HistoryReadValueId
impl Clone for HistoryReadValueId
Sourcefn clone(&self) -> HistoryReadValueId
fn clone(&self) -> HistoryReadValueId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HistoryReadValueId
impl Debug for HistoryReadValueId
Sourceimpl Default for HistoryReadValueId
impl Default for HistoryReadValueId
Sourcefn default() -> HistoryReadValueId
fn default() -> HistoryReadValueId
Returns the “default value” for a type. Read more
Sourceimpl JsonDecodable for HistoryReadValueId
impl JsonDecodable for HistoryReadValueId
Sourcefn decode(
stream: &mut JsonStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> EncodingResult<Self>
fn decode( stream: &mut JsonStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> EncodingResult<Self>
Decode Self from a JSON stream.
Sourceimpl JsonEncodable for HistoryReadValueId
impl JsonEncodable for HistoryReadValueId
Sourcefn encode(
&self,
stream: &mut JsonStreamWriter<&mut dyn Write>,
ctx: &Context<'_>,
) -> EncodingResult<()>
fn encode( &self, stream: &mut JsonStreamWriter<&mut dyn Write>, ctx: &Context<'_>, ) -> EncodingResult<()>
Write the type to the provided JSON writer.
Sourceimpl MessageInfo for HistoryReadValueId
impl MessageInfo for HistoryReadValueId
Sourcefn json_type_id(&self) -> ObjectId
fn json_type_id(&self) -> ObjectId
The JSON type id associated with the message.
Sourcefn xml_type_id(&self) -> ObjectId
fn xml_type_id(&self) -> ObjectId
The XML type id associated with the message.
Sourcefn data_type_id(&self) -> DataTypeId
fn data_type_id(&self) -> DataTypeId
The data type id associated with the message.
Sourceimpl PartialEq for HistoryReadValueId
impl PartialEq for HistoryReadValueId
Sourceimpl UaNullable for HistoryReadValueId
impl UaNullable for HistoryReadValueId
Sourcefn is_ua_null(&self) -> bool
fn is_ua_null(&self) -> bool
Return true if this value is null, meaning it can be left out when
being encoded in JSON and XML encodings.
Sourceimpl XmlDecodable for HistoryReadValueId
impl XmlDecodable for HistoryReadValueId
Sourcefn decode(
stream: &mut XmlStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> EncodingResult<Self>
fn decode( stream: &mut XmlStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> EncodingResult<Self>
Decode a value from an XML stream.
Sourceimpl XmlEncodable for HistoryReadValueId
impl XmlEncodable for HistoryReadValueId
Sourcefn encode(
&self,
stream: &mut XmlStreamWriter<&mut dyn Write>,
ctx: &Context<'_>,
) -> EncodingResult<()>
fn encode( &self, stream: &mut XmlStreamWriter<&mut dyn Write>, ctx: &Context<'_>, ) -> EncodingResult<()>
Encode a value to an XML stream.
Sourceimpl XmlType for HistoryReadValueId
impl XmlType for HistoryReadValueId
impl StructuralPartialEq for HistoryReadValueId