pub struct JsonActionNetworkMessage {
pub message_id: UAString,
pub message_type: UAString,
pub publisher_id: UAString,
pub timestamp: UtcTime,
pub response_address: UAString,
pub correlation_data: ByteString,
pub requestor_id: UAString,
pub timeout_hint: Duration,
pub messages: Option<Vec<ExtensionObject>>,
}Fields
message_id: UAStringmessage_type: UAStringpublisher_id: UAStringtimestamp: UtcTimeresponse_address: UAStringcorrelation_data: ByteStringrequestor_id: UAStringtimeout_hint: Durationmessages: Option<Vec<ExtensionObject>>Trait Implementations
Sourceimpl BinaryDecodable for JsonActionNetworkMessage
impl BinaryDecodable for JsonActionNetworkMessage
Sourcefn decode<S: Read + ?Sized>(
stream: &mut S,
ctx: &Context<'_>,
) -> EncodingResult<Self>
fn decode<S: Read + ?Sized>( stream: &mut S, ctx: &Context<'_>, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.Sourceimpl BinaryEncodable for JsonActionNetworkMessage
impl BinaryEncodable for JsonActionNetworkMessage
Sourcefn byte_len(&self, ctx: &Context<'_>) -> usize
fn byte_len(&self, ctx: &Context<'_>) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write + ?Sized>(
&self,
stream: &mut S,
ctx: &Context<'_>,
) -> EncodingResult<()>
fn encode<S: Write + ?Sized>( &self, stream: &mut S, ctx: &Context<'_>, ) -> EncodingResult<()>
Encodes the instance to the write stream.
Sourcefn override_encoding(&self) -> Option<BuiltInDataEncoding>
fn override_encoding(&self) -> Option<BuiltInDataEncoding>
Override the extension object encoding used for this type.
This only makes sense if the type can only ever be encoded using a single
built-in encoding.
Sourceimpl Clone for JsonActionNetworkMessage
impl Clone for JsonActionNetworkMessage
Sourcefn clone(&self) -> JsonActionNetworkMessage
fn clone(&self) -> JsonActionNetworkMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JsonActionNetworkMessage
impl Debug for JsonActionNetworkMessage
Sourceimpl Default for JsonActionNetworkMessage
impl Default for JsonActionNetworkMessage
Sourcefn default() -> JsonActionNetworkMessage
fn default() -> JsonActionNetworkMessage
Returns the “default value” for a type. Read more
Sourceimpl JsonDecodable for JsonActionNetworkMessage
impl JsonDecodable for JsonActionNetworkMessage
Sourcefn decode(
stream: &mut JsonStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> EncodingResult<Self>
fn decode( stream: &mut JsonStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> EncodingResult<Self>
Decode Self from a JSON stream.
Sourceimpl JsonEncodable for JsonActionNetworkMessage
impl JsonEncodable for JsonActionNetworkMessage
Sourcefn encode(
&self,
stream: &mut JsonStreamWriter<&mut dyn Write>,
ctx: &Context<'_>,
) -> EncodingResult<()>
fn encode( &self, stream: &mut JsonStreamWriter<&mut dyn Write>, ctx: &Context<'_>, ) -> EncodingResult<()>
Write the type to the provided JSON writer.
Sourceimpl PartialEq for JsonActionNetworkMessage
impl PartialEq for JsonActionNetworkMessage
Sourceimpl UaNullable for JsonActionNetworkMessage
impl UaNullable for JsonActionNetworkMessage
Sourcefn is_ua_null(&self) -> bool
fn is_ua_null(&self) -> bool
Return true if this value is null, meaning it can be left out when
being encoded in JSON and XML encodings.
Sourceimpl XmlDecodable for JsonActionNetworkMessage
impl XmlDecodable for JsonActionNetworkMessage
Sourcefn decode(
stream: &mut XmlStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> EncodingResult<Self>
fn decode( stream: &mut XmlStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> EncodingResult<Self>
Decode a value from an XML stream.
Sourceimpl XmlEncodable for JsonActionNetworkMessage
impl XmlEncodable for JsonActionNetworkMessage
Sourcefn encode(
&self,
stream: &mut XmlStreamWriter<&mut dyn Write>,
ctx: &Context<'_>,
) -> EncodingResult<()>
fn encode( &self, stream: &mut XmlStreamWriter<&mut dyn Write>, ctx: &Context<'_>, ) -> EncodingResult<()>
Encode a value to an XML stream.
Sourceimpl XmlType for JsonActionNetworkMessage
impl XmlType for JsonActionNetworkMessage
impl StructuralPartialEq for JsonActionNetworkMessage