pub struct ReadProcessedDetails {
pub start_time: UtcTime,
pub end_time: UtcTime,
pub processing_interval: Duration,
pub aggregate_type: Option<Vec<NodeId>>,
pub aggregate_configuration: AggregateConfiguration,
}Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part11/6.5.4/#6.5.4.1
Fields
start_time: UtcTimeend_time: UtcTimeprocessing_interval: Durationaggregate_type: Option<Vec<NodeId>>aggregate_configuration: AggregateConfigurationTrait Implementations
Sourceimpl BinaryDecodable for ReadProcessedDetails
impl BinaryDecodable for ReadProcessedDetails
Sourcefn decode<S: Read + ?Sized>(
stream: &mut S,
ctx: &Context<'_>,
) -> EncodingResult<Self>
fn decode<S: Read + ?Sized>( stream: &mut S, ctx: &Context<'_>, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.Sourceimpl BinaryEncodable for ReadProcessedDetails
impl BinaryEncodable for ReadProcessedDetails
Sourcefn byte_len(&self, ctx: &Context<'_>) -> usize
fn byte_len(&self, ctx: &Context<'_>) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write + ?Sized>(
&self,
stream: &mut S,
ctx: &Context<'_>,
) -> EncodingResult<()>
fn encode<S: Write + ?Sized>( &self, stream: &mut S, ctx: &Context<'_>, ) -> EncodingResult<()>
Encodes the instance to the write stream.
Sourcefn override_encoding(&self) -> Option<BuiltInDataEncoding>
fn override_encoding(&self) -> Option<BuiltInDataEncoding>
Override the extension object encoding used for this type.
This only makes sense if the type can only ever be encoded using a single
built-in encoding.
Sourceimpl Clone for ReadProcessedDetails
impl Clone for ReadProcessedDetails
Sourcefn clone(&self) -> ReadProcessedDetails
fn clone(&self) -> ReadProcessedDetails
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReadProcessedDetails
impl Debug for ReadProcessedDetails
Sourceimpl Default for ReadProcessedDetails
impl Default for ReadProcessedDetails
Sourcefn default() -> ReadProcessedDetails
fn default() -> ReadProcessedDetails
Returns the “default value” for a type. Read more
Sourceimpl JsonDecodable for ReadProcessedDetails
impl JsonDecodable for ReadProcessedDetails
Sourcefn decode(
stream: &mut JsonStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> EncodingResult<Self>
fn decode( stream: &mut JsonStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> EncodingResult<Self>
Decode Self from a JSON stream.
Sourceimpl JsonEncodable for ReadProcessedDetails
impl JsonEncodable for ReadProcessedDetails
Sourcefn encode(
&self,
stream: &mut JsonStreamWriter<&mut dyn Write>,
ctx: &Context<'_>,
) -> EncodingResult<()>
fn encode( &self, stream: &mut JsonStreamWriter<&mut dyn Write>, ctx: &Context<'_>, ) -> EncodingResult<()>
Write the type to the provided JSON writer.
Sourceimpl MessageInfo for ReadProcessedDetails
impl MessageInfo for ReadProcessedDetails
Sourcefn json_type_id(&self) -> ObjectId
fn json_type_id(&self) -> ObjectId
The JSON type id associated with the message.
Sourcefn xml_type_id(&self) -> ObjectId
fn xml_type_id(&self) -> ObjectId
The XML type id associated with the message.
Sourcefn data_type_id(&self) -> DataTypeId
fn data_type_id(&self) -> DataTypeId
The data type id associated with the message.
Sourceimpl PartialEq for ReadProcessedDetails
impl PartialEq for ReadProcessedDetails
Sourceimpl UaNullable for ReadProcessedDetails
impl UaNullable for ReadProcessedDetails
Sourcefn is_ua_null(&self) -> bool
fn is_ua_null(&self) -> bool
Return true if this value is null, meaning it can be left out when
being encoded in JSON and XML encodings.
Sourceimpl XmlDecodable for ReadProcessedDetails
impl XmlDecodable for ReadProcessedDetails
Sourcefn decode(
stream: &mut XmlStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> EncodingResult<Self>
fn decode( stream: &mut XmlStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> EncodingResult<Self>
Decode a value from an XML stream.
Sourceimpl XmlEncodable for ReadProcessedDetails
impl XmlEncodable for ReadProcessedDetails
Sourcefn encode(
&self,
stream: &mut XmlStreamWriter<&mut dyn Write>,
ctx: &Context<'_>,
) -> EncodingResult<()>
fn encode( &self, stream: &mut XmlStreamWriter<&mut dyn Write>, ctx: &Context<'_>, ) -> EncodingResult<()>
Encode a value to an XML stream.
Sourceimpl XmlType for ReadProcessedDetails
impl XmlType for ReadProcessedDetails
impl StructuralPartialEq for ReadProcessedDetails