Enum opcua_types::variant::Variant[][src]

pub enum Variant {
Show 24 variants Empty, Boolean(bool), SByte(i8), Byte(u8), Int16(i16), UInt16(u16), Int32(i32), UInt32(u32), Int64(i64), UInt64(u64), Float(f32), Double(f64), String(UAString), DateTime(Box<DateTime>), Guid(Box<Guid>), StatusCode(StatusCode), ByteString(ByteString), XmlElement(XmlElement), QualifiedName(Box<QualifiedName>), LocalizedText(Box<LocalizedText>), NodeId(Box<NodeId>), ExpandedNodeId(Box<ExpandedNodeId>), ExtensionObject(Box<ExtensionObject>), Array(Box<Array>),
}
A Variant holds built-in OPC UA data types, including single and multi dimensional arrays, data values and extension objects.

As variants may be passed around a lot on the stack, Boxes are used for more complex types to keep the size of this type down a bit, especially when used in arrays.

Variants

Empty

Empty type has no value. It is equivalent to a Null value (part 6 5.1.6)

Boolean

Boolean

Tuple Fields of Boolean

0: bool
SByte

Signed byte

Tuple Fields of SByte

0: i8
Byte

Unsigned byte

Tuple Fields of Byte

0: u8
Int16

Signed 16-bit int

Tuple Fields of Int16

0: i16
UInt16

Unsigned 16-bit int

Tuple Fields of UInt16

0: u16
Int32

Signed 32-bit int

Tuple Fields of Int32

0: i32
UInt32

Unsigned 32-bit int

Tuple Fields of UInt32

0: u32
Int64

Signed 64-bit int

Tuple Fields of Int64

0: i64
UInt64

Unsigned 64-bit int

Tuple Fields of UInt64

0: u64
Float

Float

Tuple Fields of Float

0: f32
Double

Double

Tuple Fields of Double

0: f64
String

String

Tuple Fields of String

0: UAString
DateTime

DateTime

Tuple Fields of DateTime

0: Box<DateTime>
Guid

Guid

Tuple Fields of Guid

0: Box<Guid>
StatusCode

StatusCode

Tuple Fields of StatusCode

0: StatusCode
ByteString

ByteString

Tuple Fields of ByteString

0: ByteString
XmlElement

XmlElement

Tuple Fields of XmlElement

0: XmlElement
QualifiedName

QualifiedName

Tuple Fields of QualifiedName

0: Box<QualifiedName>
LocalizedText

LocalizedText

Tuple Fields of LocalizedText

0: Box<LocalizedText>
NodeId

NodeId

Tuple Fields of NodeId

0: Box<NodeId>
ExpandedNodeId

ExpandedNodeId

Tuple Fields of ExpandedNodeId

0: Box<ExpandedNodeId>
ExtensionObject

ExtensionObject

Tuple Fields of ExtensionObject

0: Box<ExtensionObject>
Array

Single dimension array which can contain any scalar type, all the same type. Nested arrays will be rejected.

Tuple Fields of Array

0: Box<Array>

Implementations

Test the flag (convenience method)

Performs an EXPLICIT cast from one type to another. This will first attempt an implicit conversion and only then attempt to cast. Casting is potentially lossy.

Performs an IMPLICIT conversion from one type to another

Tests and returns true if the variant holds a numeric type

Test if the variant holds an array

Tests that the variant is in a valid state. In particular for arrays ensuring that the values are all acceptable and for a multi dimensional array that the dimensions equal the actual values.

Converts the numeric type to a double or returns None

This function is for a special edge case of converting a byte string to a single array of bytes

This function gets a range of values from the variant if it is an array, or returns a clone of the variant itself.