pub enum VariantTypeId<'a> {
Empty,
Scalar(VariantScalarTypeId),
Array(VariantScalarTypeId, Option<&'a [u32]>),
}Expand description
The variant type id is the type of the variant but without its payload.
Variants
Empty
The variant is empty.
Scalar(VariantScalarTypeId)
The variant is a scalar with this inner type.
Array(VariantScalarTypeId, Option<&'a [u32]>)
The variant is an array with this inner type and optionally these ArrayDimensions.
Implementations
Sourceimpl VariantTypeId<'_>
impl VariantTypeId<'_>
Sourcepub fn encoding_mask(&self) -> u8
pub fn encoding_mask(&self) -> u8
Get the encoding mask.
Sourcepub fn precedence(&self) -> u8
pub fn precedence(&self) -> u8
Get the precedence when converting between different variant types.