pub struct XmlElement {
pub text: Option<String>,
pub tag: String,
pub attributes: HashMap<String, String>,
pub children: HashMap<String, Vec<XmlElement>>,
}Expand description
Full XML element, requires further type information to convert to a data type.
Fields
text: Option<String>XML Element body.
tag: StringTag name.
attributes: HashMap<String, String>Map of attribute names to values.
children: HashMap<String, Vec<XmlElement>>Map of child tag names to value.
Implementations
Sourceimpl XmlElement
impl XmlElement
Sourcepub fn children_with_name<'a>(
&'a self,
name: &'a str,
) -> impl Iterator<Item = &'a XmlElement> + 'a
pub fn children_with_name<'a>( &'a self, name: &'a str, ) -> impl Iterator<Item = &'a XmlElement> + 'a
Get all children of this node with the given name.
Sourcepub fn first_child_with_name<'a>(
&'a self,
name: &'a str,
) -> Option<&'a XmlElement>
pub fn first_child_with_name<'a>( &'a self, name: &'a str, ) -> Option<&'a XmlElement>
Get the first child with the given name.
Sourcepub fn child_content<'a>(&'a self, name: &'a str) -> Option<&'a str>
pub fn child_content<'a>(&'a self, name: &'a str) -> Option<&'a str>
Get the content of the first child with the given name.