The Array type, used to contain OPC-UA arrays, which are potentially
multi-dimensional, but stored as a single vector of Variants.
Structs
- Array
- An array is a vector of values with an optional number of dimensions. It is expected that the multi-dimensional array is valid, or it might not be encoded or decoded properly. The dimensions should match the number of values, or the array is invalid.
Enums
- Array
Error - Error returned when creating arrays.
Functions
- values_
are_ of_ type - Check that all elements in the slice of arrays are the same type.