Struct opcua_types::basic_types::ExtensionObject
[−]
[src]
pub struct ExtensionObject {
pub node_id: NodeId,
pub body: ExtensionObjectEncoding,
}A structure that contains an application specific data type that may not be recognized by the receiver. Data type ID 22
Fields
node_id: NodeId
body: ExtensionObjectEncoding
Methods
impl ExtensionObject[src]
fn null() -> ExtensionObject[src]
Creates a null extension object, i.e. one with no value or payload
fn is_null(&self) -> bool[src]
fn is_empty(&self) -> bool[src]
fn from_encodable<N, T>(node_id: N, encodable: T) -> ExtensionObject where
N: 'static + Into<NodeId>,
T: BinaryEncoder<T>, [src]
N: 'static + Into<NodeId>,
T: BinaryEncoder<T>,
Creates an extension object with the specified node id and the encodable object as its payload. The body is set to a byte string containing the encoded struct.
fn decode_inner<T>(&self) -> EncodingResult<T> where
T: BinaryEncoder<T>, [src]
T: BinaryEncoder<T>,
Decodes the inner content of the extension object and returns it. The node id is ignored for decoding. The caller supplies the binary encoder impl that should be used to extract the data. Errors result in a decoding error.