Struct opcua_types::basic_types::QualifiedName
[−]
[src]
pub struct QualifiedName {
pub namespace_index: UInt16,
pub name: UAString,
}A numeric identifier for a error or condition that is associated with a value or an operation. Data type ID 19 A name qualified by a namespace. Data type ID 20
Fields
namespace_index: UInt16
The namespace index.
name: UAString
The name.
Methods
impl QualifiedName[src]
fn new(namespace_index: UInt16, name: &str) -> QualifiedName[src]
fn null() -> QualifiedName[src]
fn is_null(&self) -> bool[src]