Struct opcua_types::byte_string::ByteString
[−]
[src]
pub struct ByteString {
pub value: Option<Vec<u8>>,
}A sequence of octets.
Fields
value: Option<Vec<u8>>
Methods
impl ByteString[src]
fn null() -> ByteString[src]
Create a null string (not the same as an empty string)
fn is_null(&self) -> bool[src]
Test if the string is null
fn is_null_or_empty(&self) -> bool[src]
Test if the string is null or empty
fn from_base64(data: &str) -> Option<ByteString>[src]
Creates a byte string from a Base64 encoded string
fn as_base64(&self) -> String[src]
Encodes the bytestring as a Base64 encoded string
fn nonce() -> ByteString[src]
Creates a nonce - 32 bytes of random data
fn random(number_of_bytes: usize) -> ByteString[src]
Create a byte string with a number of random characters. Can be used to create a nonce or a similar reason.