Enum opcua_types::data_types::MessageSecurityMode
[−]
[src]
pub enum MessageSecurityMode {
Invalid,
None,
Sign,
SignAndEncrypt,
}The MessageSecurityMode is an enumeration that specifies what security should be applied to messages exchanges during a Session.
Variants
InvalidThe MessageSecurityMode is invalid. This value is the default value to avoid an accidental choice of no security is applied. This choice will always be rejected.
NoneNo security is applied.
SignAll messages are signed but not encrypted.
SignAndEncryptAll messages are signed and encrypted.