Struct opcua_types::data_value::DataValue [] [src]

pub struct DataValue {
    pub value: Option<Variant>,
    pub status: Option<StatusCode>,
    pub source_timestamp: Option<DateTime>,
    pub source_picoseconds: Option<Int16>,
    pub server_timestamp: Option<DateTime>,
    pub server_picoseconds: Option<Int16>,
}

Data type ID 23

Fields

The value. BaseDataType Not present if the Value bit in the EncodingMask is False.

The status associated with the value. Not present if the StatusCode bit in the EncodingMask is False

The source timestamp associated with the value. Not present if the SourceTimestamp bit in the EncodingMask is False.

The number of 10 picosecond intervals for the SourceTimestamp. Not present if the SourcePicoSeconds bit in the EncodingMask is False. If the source timestamp is missing the picoseconds are ignored.

The Server timestamp associated with the value. Not present if the ServerTimestamp bit in the EncodingMask is False.

The number of 10 picosecond intervals for the ServerTimestamp. Not present if the ServerPicoSeconds bit in the EncodingMask is False. If the Server timestamp is missing the picoseconds are ignored.

Methods

impl DataValue
[src]

[src]

[src]