pub struct NodeId {
pub namespace: u16,
pub identifier: Identifier,
}Expand description
An identifier for a node in the address space of an OPC UA Server.
Fields
namespace: u16The index for a namespace
identifier: IdentifierThe identifier for the node in the address space
Implementations
Sourceimpl NodeId
impl NodeId
Sourcepub fn new<T>(namespace: u16, value: T) -> NodeIdwhere
T: Into<Identifier>,
pub fn new<T>(namespace: u16, value: T) -> NodeIdwhere
T: Into<Identifier>,
Constructs a new NodeId from anything that can be turned into Identifier u32, Guid, ByteString or String
Sourcepub fn root_folder_id() -> NodeId
pub fn root_folder_id() -> NodeId
Returns the node id for the root folder.
Sourcepub fn objects_folder_id() -> NodeId
pub fn objects_folder_id() -> NodeId
Returns the node id for the objects folder.
Sourcepub fn types_folder_id() -> NodeId
pub fn types_folder_id() -> NodeId
Returns the node id for the types folder.
Sourcepub fn views_folder_id() -> NodeId
pub fn views_folder_id() -> NodeId
Returns the node id for the views folder.
Sourcepub fn next_numeric(namespace: u16) -> NodeId
pub fn next_numeric(namespace: u16) -> NodeId
Creates a numeric node id with an id incrementing up from 1000
Sourcepub fn as_object_id(&self) -> Result<ObjectId, NodeIdError>
pub fn as_object_id(&self) -> Result<ObjectId, NodeIdError>
Extracts an ObjectId from a node id, providing the node id holds an object id
Sourcepub fn as_variable_id(&self) -> Result<VariableId, NodeIdError>
pub fn as_variable_id(&self) -> Result<VariableId, NodeIdError>
Try to convert this to a builtin variable ID.
Sourcepub fn as_reference_type_id(&self) -> Result<ReferenceTypeId, NodeIdError>
pub fn as_reference_type_id(&self) -> Result<ReferenceTypeId, NodeIdError>
Try to convert this to a builtin reference type ID.
Sourcepub fn as_data_type_id(&self) -> Result<DataTypeId, NodeIdError>
pub fn as_data_type_id(&self) -> Result<DataTypeId, NodeIdError>
Try to convert this to a builtin data type ID.
Sourcepub fn as_method_id(&self) -> Result<MethodId, NodeIdError>
pub fn as_method_id(&self) -> Result<MethodId, NodeIdError>
Try to convert this to a builtin method ID.
Sourcepub fn is_numeric(&self) -> bool
pub fn is_numeric(&self) -> bool
Test if the node id is numeric
Sourcepub fn is_byte_string(&self) -> bool
pub fn is_byte_string(&self) -> bool
Test if the node id us a byte string