Struct opcua_types::node_id::NodeId [−][src]
pub struct NodeId {
pub namespace: u16,
pub identifier: Identifier,
}Expand description
An identifier for a node in the address space of an OPC UA Server.
Fields
namespace: u16The index for a namespace
identifier: IdentifierThe identifier for the node in the address space
Implementations
Returns the node id for the root folder.
Returns the node id for the objects folder.
Returns the node id for the types folder.
Returns the node id for the views folder.
Extracts an ObjectId from a node id, providing the node id holds an object id
Test if the node id is numeric
Test if the node id us a byte string