Struct opcua_types::node_id::NodeId [] [src]

pub struct NodeId {
    pub namespace: UInt16,
    pub identifier: Identifier,
}

An identifier for a node in the address space of an OPC UA Server.

Fields

The index for a namespace

The identifier for the node in the address space

Methods

impl NodeId
[src]

[src]

[src]

Construct a string node id

[src]

Test if the node id is null, i.e. 0 namespace and 0 identifier

[src]

Returns a null node id

[src]

[src]

Extracts an ObjectId from a node id, providing the node id holds an object id

[src]

[src]

[src]

Test if the node id is numeric

[src]

Test if the node id is a string

[src]

Test if the node id is a guid

[src]

Test if the node id us a byte string