Struct opcua_types::node_id::NodeId
[−]
[src]
pub struct NodeId {
pub namespace: UInt16,
pub identifier: Identifier,
}An identifier for a node in the address space of an OPC UA Server.
Fields
namespace: UInt16
The index for a namespace
identifier: Identifier
The identifier for the node in the address space
Methods
impl NodeId[src]
fn new<T>(namespace: UInt16, value: T) -> NodeId where
T: 'static + Into<Identifier>, [src]
T: 'static + Into<Identifier>,
fn new_string(namespace: UInt16, value: &str) -> NodeId[src]
Construct a string node id
fn is_null(&self) -> bool[src]
Test if the node id is null, i.e. 0 namespace and 0 identifier
fn null() -> NodeId[src]
Returns a null node id
fn next_numeric() -> NodeId[src]
fn as_object_id(&self) -> Result<ObjectId, ()>[src]
Extracts an ObjectId from a node id, providing the node id holds an object id
fn as_reference_type_id(&self) -> Result<ReferenceTypeId, ()>[src]
fn to_string(&self) -> String[src]
fn is_numeric(&self) -> bool[src]
Test if the node id is numeric
fn is_string(&self) -> bool[src]
Test if the node id is a string
fn is_guid(&self) -> bool[src]
Test if the node id is a guid
fn is_byte_string(&self) -> bool[src]
Test if the node id us a byte string