pub enum Operand {
ElementOperand(ElementOperand),
LiteralOperand(LiteralOperand),
AttributeOperand(AttributeOperand),
SimpleAttributeOperand(SimpleAttributeOperand),
}Expand description
A filter operand.
Variants
ElementOperand(ElementOperand)
Operand pointing at another filter element.
LiteralOperand(LiteralOperand)
Operand resolving to a literal value.
AttributeOperand(AttributeOperand)
Operand resolving to an attribute of some node.
SimpleAttributeOperand(SimpleAttributeOperand)
Operand resolving to an attribute of some type.
Implementations
Sourceimpl Operand
impl Operand
Sourcepub fn literal<T>(literal: T) -> Operandwhere
T: Into<LiteralOperand>,
pub fn literal<T>(literal: T) -> Operandwhere
T: Into<LiteralOperand>,
Create a literal operand with the given type.
Sourcepub fn simple_attribute<T>(
type_definition_id: T,
browse_path: &str,
attribute_id: AttributeId,
index_range: NumericRange,
) -> Operand
pub fn simple_attribute<T>( type_definition_id: T, browse_path: &str, attribute_id: AttributeId, index_range: NumericRange, ) -> Operand
Creates a simple attribute operand. The browse path is the browse name using / as a separator.
Sourcepub fn operand_type(&self) -> OperandType
pub fn operand_type(&self) -> OperandType
Get the operand type.
Sourcepub fn is_element(&self) -> bool
pub fn is_element(&self) -> bool
Return true if the operand is an element operand.
Sourcepub fn is_literal(&self) -> bool
pub fn is_literal(&self) -> bool
Return true if the operand is a literal operand.
Sourcepub fn is_attribute(&self) -> bool
pub fn is_attribute(&self) -> bool
Return true if the operand is an attribute operand.
Sourcepub fn is_simple_attribute(&self) -> bool
pub fn is_simple_attribute(&self) -> bool
Return true if the operand is a simple attribute operand.