pub struct ResponseHeader {
pub timestamp: UtcTime,
pub request_handle: IntegerId,
pub service_result: StatusCode,
pub service_diagnostics: DiagnosticInfo,
pub string_table: Option<Vec<UAString>>,
pub additional_header: ExtensionObject,
}Expand description
The ResponseHeader contains information common to every response from server to client.
Fields
timestamp: UtcTimeResponse timestamp.
request_handle: IntegerIdHandle of the request this message is responding to.
service_result: StatusCodeStatus of the service call as a whole.
service_diagnostics: DiagnosticInfoRequested diagnostics.
string_table: Option<Vec<UAString>>String table for the message.
additional_header: ExtensionObjectReserved space for additional header details.
Implementations
Sourceimpl ResponseHeader
impl ResponseHeader
Sourcepub fn new_good(request_header: impl AsRequestHandle) -> ResponseHeader
pub fn new_good(request_header: impl AsRequestHandle) -> ResponseHeader
Create a new response header with status Good.
Sourcepub fn new_service_result(
request_header: impl AsRequestHandle,
service_result: StatusCode,
) -> ResponseHeader
pub fn new_service_result( request_header: impl AsRequestHandle, service_result: StatusCode, ) -> ResponseHeader
Create a new response header with given status.
Sourcepub fn new_timestamped_service_result(
timestamp: DateTime,
request_header: impl AsRequestHandle,
service_result: StatusCode,
) -> ResponseHeader
pub fn new_timestamped_service_result( timestamp: DateTime, request_header: impl AsRequestHandle, service_result: StatusCode, ) -> ResponseHeader
Create a new response header with given status and timestamp.
Sourcepub fn null() -> ResponseHeader
pub fn null() -> ResponseHeader
For testing, nothing else