Struct opcua_types::string::UAString
[−]
[src]
pub struct UAString {
pub value: Option<String>,
}A UTF-8 encoded sequence of Unicode characters.
A string can hold a null value, so the string value is optional. When there is no string, the value is treated as null
To avoid naming conflict hell, the String type is named UAString.
Data type ID 12
Fields
value: Option<String>
Methods
impl UAString[src]
fn len(&self) -> isize[src]
Returns the length of the string or -1 for null
fn null() -> UAString[src]
Create a null string (not the same as an empty string)
fn is_null(&self) -> bool[src]
Test if the string is null