Enum opcua_types::variant::VariantTypeId [−][src]
pub enum VariantTypeId {
Show 24 variants
Empty,
Boolean,
SByte,
Byte,
Int16,
UInt16,
Int32,
UInt32,
Int64,
UInt64,
Float,
Double,
String,
DateTime,
Guid,
StatusCode,
ByteString,
XmlElement,
QualifiedName,
LocalizedText,
NodeId,
ExpandedNodeId,
ExtensionObject,
Array,
}Expand description
The variant type id is the type of the variant but without its payload.
Variants
Implementations
Tests and returns true if the variant holds a numeric type
Returns a data precedence rank for scalar types, OPC UA part 4 table 119. This is used when operators are comparing values of differing types. The type with the highest precedence dictates how values are converted in order to be compared.